@@ -72,7 +72,7 @@ struct DLL_LOCAL StreamDumper {
 
 bool DLL_LOCAL looksLikeHtmlAndNotAUrl(QString str) {
 	QString s = str.split("?")[0];
-	return s.count('<') > 0 || s.count('<') > 0;
+	return s.count('<') > 0 || str.startsWith("data:", Qt::CaseInsensitive);
 }
 
 PdfConverterPrivate::PdfConverterPrivate(PdfGlobal & s, PdfConverter & o) :
@@ -579,9 +579,7 @@ void PdfConverterPrivate::findLinks(QWebFrame * frame, QVector<QPair<QWebElement
 					}
 				}
 			} else if (uexternal) {
-				// pass the unresolved url to WebKit. WebKit will resolve it
-				// depending upon the type of url - filepath, web-uri etc.
-				external.push_back( qMakePair(elm, h) );
+				external.push_back( qMakePair(elm, settings.resolveRelativeLinks ? href.toString() : h) );
 			}
 		}
 	}
@@ -1025,18 +1023,22 @@ void PdfConverterPrivate::printDocument() {
 			!o.open(stdout,QIODevice::WriteOnly) ||
 			!MultiPageLoader::copyFile(i,o) ) {
 			emit out.error("Count not write to stdout");
+			tempOut.removeAll();
 			fail();
 			return;
 		}
+		tempOut.removeAll();
 	}
 
 	if (settings.out.isEmpty()) {
 		QFile i(lout);
 		if (!i.open(QIODevice::ReadOnly)) {
 			emit out.error("Reading output failed");
+			tempOut.removeAll();
 			fail();
 		}
 		outputData = i.readAll();
+		tempOut.removeAll();
 	}
 	clearResources();
 #ifdef __EXTENSIVE_WKHTMLTOPDF_QT_HACK__
